Class: MiniTest::Unit::TestCase
- Inherits:
-
Object
- Object
- MiniTest::Unit::TestCase
- Defined in:
- lib/pry-rescue/minitest.rb
Overview
TODO: it should be possible to do all this by simply wrapping MiniTest::Unit::TestCase in recent versions of minitest. Unfortunately the version of minitest bundled with ruby seems to take precedence over the new gem, so we can’t do this and still support ruby-1.9.3
Instance Method Summary collapse
Instance Method Details
#run(runner) ⇒ Object
31 32 33 34 35 |
# File 'lib/pry-rescue/minitest.rb', line 31 def run(runner) Pry::rescue do run_without_rescue(runner) end end |
#run_without_rescue ⇒ Object
29 |
# File 'lib/pry-rescue/minitest.rb', line 29 alias_method :run_without_rescue, :run |